$(document).ready(function () {
    $('#searchBtn').on('click', function () {
        // 获取输入条件
        const condition1 = $('#condition1').val().trim();
        const condition2 = $('#condition2').val().trim();

        // 判断是否有输入条件
        if (!condition1 && !condition2) {
            alert('请至少输入一个查询条件');
            return;
        }

        // 获取当前页面的基础路径
        const baseUrl = window.location.origin; // 获取 http://localhost:9990
        const apiPath = '/api/dag/post'; // 接口的路径
        const apiUrl = `${baseUrl}${apiPath}`; // 完整的接口地址

        // 显示加载提示（可选）
        $('#searchBtn').text('查询中...').prop('disabled', true);

        // 发起 AJAX 请求
        $.ajax({
            url: apiUrl, // 替换为实际接口地址
            method: 'GET',
            data: { addressee:condition1, stuNumber:condition2 },
            dataType: 'json',
            success: function (res) {
                // 清空之前的结果
                const tbody = $('#resultsBody');
                tbody.empty();
                let data = res.data;
                if (data.length > 0) {
                    // 动态生成表格内容
                    data.forEach(item => {
                        const row = `
                            <tr>
                                <td class="copyable">${item.addressee}</td>
                                <td class="copyable">${item.stuNumber}</td>
                                <td class="copyable">${item.postcode}</td>
                                <td class="copyable">${item.address}</td>
                                <td class="copyable">${item.telephone}</td>
                                <td class="copyable">${item.emsMunber}</td>
                            </tr>
                        `;
                        tbody.append(row);
                    });

                    // 显示表格
                    $('#resultsTable').show();
                } else {
                    // 隐藏表格并提示无结果
                    $('#resultsTable').hide();
                    alert('未找到相关记录');
                }
            },
            error: function (xhr, status, error) {
                console.error('请求失败:', error);
                alert('查询失败，请稍后再试');
            },
            complete: function () {
                // 恢复按钮状态
                $('#searchBtn').text('Search').prop('disabled', false);
            }
        });
    });

    // 点击复制逻辑
    $('#resultsTable').on('click', '.copyable', function () {
        const text = $(this).text().trim();
        navigator.clipboard.writeText(text).then(() => {
            alert(`已复制内容: ${text}`);
        }).catch(err => {
            console.error('复制失败:', err);
            alert('复制失败，请稍后重试');
        });
    });
});
